@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use meta;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 sub import {
 	my $caller = caller();
@@ -51,11 +51,11 @@ sub import {
 
 =head1 NAME
 
-Xerarch - Xerarch
+Xerarch - Introspection
 
 =head1 VERSION
 
-Version 0.02
+Version 0.03
 
 =cut
 
@@ -140,8 +140,6 @@ the web interface at L<https://rt.cpan.org/NoAuth/ReportBug.html?Queue=Xerarch>.
 automatically be notified of progress on your bug as I make changes.
 
 
-
-
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
